diff --git a/src/common/pages/build.js b/src/common/pages/code.js
similarity index 97%
rename from src/common/pages/build.js
rename to src/common/pages/code.js
index af7b5828..b73b80ce 100644
--- a/src/common/pages/build.js
+++ b/src/common/pages/code.js
@@ -178,7 +178,7 @@ async function editFacet(ogFacet) {
}
// Scroll to builder
- document.querySelector("#build")?.scrollIntoView();
+ document.querySelector("#code")?.scrollIntoView();
// Make sure HTML is loaded
if (!facet.html && facet.uri) {
@@ -212,7 +212,7 @@ export function handleBuildFormSubmit() {
const editor = $editor.value;
if (!editor) return;
- document.querySelector("#build-form")?.addEventListener(
+ document.querySelector("#code-form")?.addEventListener(
"submit",
onBuildSubmit(editor),
);
@@ -254,7 +254,7 @@ export function listenForExamplesEdit() {
});
setEditorLoading(false);
editFacet(facet);
- document.querySelector("#build")?.scrollIntoView();
+ document.querySelector("#code")?.scrollIntoView();
break;
}
}
diff --git a/src/elements.vto b/src/elements.vto
index 4df7ea31..9df02f92 100644
--- a/src/elements.vto
+++ b/src/elements.vto
@@ -230,7 +230,7 @@ definitions:
Elements
- Diffuse was built using these web components, consume these using the build tool, the Javascript package, or the linked Javascript files down below.
+ Diffuse was built using these web components, consume these using the code tool, the Javascript package, or the linked Javascript files down below.
diff --git a/src/common/pages/ppr.js b/src/common/pages/ppr.js
index 28fc1567..a80bc7d1 100644
--- a/src/common/pages/ppr.js
+++ b/src/common/pages/ppr.js
@@ -1,4 +1,4 @@
-import * as Build from "./build.js";
+import * as Build from "./code.js";
import * as Dashboard from "./dashboard.js";
import * as Grid from "./grid.js";
import * as Guide from "./guide.js";
@@ -9,7 +9,7 @@ const BASE_PATHNAME = new URL(document.baseURI).pathname;
/**
* Strips the app's base path prefix from an absolute pathname,
* returning a root-relative path like "/build".
*
* @param {string} pathname
*/
@@ -36,7 +36,7 @@ async function initJsBasedOnPage(url) {
await Grid.setupOutputIndicator();
switch (path) {
- case "/build":
+ case "/code":
Build.renderEditor();
Build.handleBuildFormSubmit();
Build.listenForExamplesEdit();
@@ -9,7 +9,7 @@ const BASE_PATHNAME = new URL(document.baseURI).pathname;
/**
* Strips the app's base path prefix from an absolute pathname,
- * returning a root-relative path like "/build".
+ * returning a root-relative path like "/code".
*
* @param {string} pathname